Springheel_jacky Documentation
==============================

This is a simple Python library and command-line tool to work with
`Springheel <https://www.twinkle-night.net/Code/springheel.html>`_ sites
without scraping. When generating a site, Springheel creates a JSON
endpoints file; parsing this file allows programs to request resources
from the site easily, without mucking around in the HTML. It's not quite
an API, but for a static site, it's close enough.

springheel_jacky depends on:

+ `requests <https://pypi.org/project/requests/>`_
+ `html-text <https://pypi.org/project/html-text/>`_

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   modules
   api
   manual
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
